@@ -2,6 +2,8 @@ package Test::Smoke::App::SyncTree;
 use warnings;
 use strict;
 
+our $VERSION = '0.001';
+
 use base 'Test::Smoke::App::Base';
 
 use Test::Smoke::Syncer;
@@ -51,7 +53,7 @@ sub new {
     my $self = $class->SUPER::new(@_);
 
     $self->{_syncer} = Test::Smoke::Syncer->new(
-        $self->option('syncer'),
+        $self->option('sync_type'),
         $self->options,
         v => $self->option('verbose'),
     );
@@ -74,6 +76,7 @@ sub run {
         $self->option('ddir'),
         $patchlevel
     );
+    return $patchlevel;
 }
 
 1;
